# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetMonitoringRegionsResult',
    'AwaitableGetMonitoringRegionsResult',
    'get_monitoring_regions',
    'get_monitoring_regions_output',
]

@pulumi.output_type
class GetMonitoringRegionsResult:
    """
    A collection of values returned by getMonitoringRegions.
    """
    def __init__(__self__, id=None, regions=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def regions(self) -> Optional[Sequence['outputs.GetMonitoringRegionsRegionResult']]:
        """
        A set of the available monitoring regions. Regions is
        documented below.
        """
        return pulumi.get(self, "regions")


class AwaitableGetMonitoringRegionsResult(GetMonitoringRegionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMonitoringRegionsResult(
            id=self.id,
            regions=self.regions)


def get_monitoring_regions(regions: Optional[Sequence[Union['GetMonitoringRegionsRegionArgs', 'GetMonitoringRegionsRegionArgsDict']]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMonitoringRegionsResult:
    """
    Provides details of all available monitoring regions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ns1 as ns1

    # Get details of all available monitoring regions.
    example = ns1.get_monitoring_regions()
    ```


    :param Sequence[Union['GetMonitoringRegionsRegionArgs', 'GetMonitoringRegionsRegionArgsDict']] regions: A set of the available monitoring regions. Regions is
           documented below.
    """
    __args__ = dict()
    __args__['regions'] = regions
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ns1:index/getMonitoringRegions:getMonitoringRegions', __args__, opts=opts, typ=GetMonitoringRegionsResult).value

    return AwaitableGetMonitoringRegionsResult(
        id=pulumi.get(__ret__, 'id'),
        regions=pulumi.get(__ret__, 'regions'))
def get_monitoring_regions_output(regions: Optional[pulumi.Input[Optional[Sequence[Union['GetMonitoringRegionsRegionArgs', 'GetMonitoringRegionsRegionArgsDict']]]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMonitoringRegionsResult]:
    """
    Provides details of all available monitoring regions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ns1 as ns1

    # Get details of all available monitoring regions.
    example = ns1.get_monitoring_regions()
    ```


    :param Sequence[Union['GetMonitoringRegionsRegionArgs', 'GetMonitoringRegionsRegionArgsDict']] regions: A set of the available monitoring regions. Regions is
           documented below.
    """
    __args__ = dict()
    __args__['regions'] = regions
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ns1:index/getMonitoringRegions:getMonitoringRegions', __args__, opts=opts, typ=GetMonitoringRegionsResult)
    return __ret__.apply(lambda __response__: GetMonitoringRegionsResult(
        id=pulumi.get(__response__, 'id'),
        regions=pulumi.get(__response__, 'regions')))
